@@ -19,8 +19,7 @@
 #'     (h0 = max growth rate * lag phase).
 #' }
 #'
-#' @return vector of dependent variable (\code{y}) and its log-transformed
-#'   values (\code{log_y}).
+#' @return vector of dependent variable (\code{y}).
 #'
 #'
 #'
@@ -52,7 +51,7 @@ grow_baranyi <- function(time, parms) {
     #log_y <- y0 + mumax * A - log(1 + (exp(mumax * A) - 1)/(exp(K - y0)))
     log_y <- log(y0) + mumax * A - log(1 + (exp(mumax * A) - 1) / exp(log(K) - log(y0)))
 
-    return(as.matrix(data.frame(time = time, y = exp(log_y), log_y = log_y)))
+    return(as.matrix(data.frame(time = time, y = exp(log_y))))
   })
 }
 ## attach names of parameters as attributes
